@@ -59,7 +59,9 @@ pref("general.warnOnAboutConfig", true);
 pref("browser.bookmarks.max_backups",       5);
 
 pref("browser.cache.disk.enable",           true);
+//@line 63 "/builds/moz2_slave/mozilla-1.9.2-linux-nightly/build/modules/libpref/src/init/all.js"
 pref("browser.cache.disk.capacity",         51200);
+//@line 67 "/builds/moz2_slave/mozilla-1.9.2-linux-nightly/build/modules/libpref/src/init/all.js"
 pref("browser.cache.memory.enable",         true);
 //pref("browser.cache.memory.capacity",     -1);
 // -1 = determine dynamically, 0 = none, n = memory capacity in kilobytes
@@ -68,6 +70,7 @@ pref("browser.cache.disk_cache_ssl",        false);
 pref("browser.cache.check_doc_frequency",   3);
 
 pref("browser.cache.offline.enable",           true);
+//@line 76 "/builds/moz2_slave/mozilla-1.9.2-linux-nightly/build/modules/libpref/src/init/all.js"
 // offline cache capacity in kilobytes
 pref("browser.cache.offline.capacity",         512000);
 
@@ -78,11 +81,14 @@ pref("offline-apps.quota.max",        204800);
 // the user should be warned if offline app disk usage exceeds this amount
 // (in kilobytes)
 pref("offline-apps.quota.warn",        51200);
+//@line 92 "/builds/moz2_slave/mozilla-1.9.2-linux-nightly/build/modules/libpref/src/init/all.js"
 
 // Fastback caching - if this pref is negative, then we calculate the number
 // of content viewers to cache based on the amount of available memory.
 pref("browser.sessionhistory.max_total_viewers", -1);
 
+pref("ui.use_native_colors", true);
+pref("ui.use_native_popup_windows", false);
 pref("browser.display.use_document_fonts",  1);  // 0 = never, 1 = quick, 2 = always
 pref("browser.display.use_document_colors", true);
 pref("browser.display.use_system_colors",   false);
@@ -102,6 +108,7 @@ pref("browser.visited_color",               "#551A8B");
 pref("browser.underline_anchors",           true);
 pref("browser.blink_allowed",               true);
 pref("browser.enable_automatic_image_resizing", false);
+pref("browser.enable_click_image_resizing", true);
 
 // See http://whatwg.org/specs/web-apps/current-work/#ping
 pref("browser.send_pings", false);
@@ -138,11 +145,11 @@ pref("media.enforce_same_site_origin", false);
 // Media cache size in kilobytes
 pref("media.cache_size", 51200);
 
-//@line 142 "/builds/slave/191-lnx-ntly/build/modules/libpref/src/init/all.js"
+//@line 156 "/builds/moz2_slave/mozilla-1.9.2-linux-nightly/build/modules/libpref/src/init/all.js"
 pref("media.ogg.enabled", true);
-//@line 145 "/builds/slave/191-lnx-ntly/build/modules/libpref/src/init/all.js"
+//@line 159 "/builds/moz2_slave/mozilla-1.9.2-linux-nightly/build/modules/libpref/src/init/all.js"
 pref("media.wave.enabled", true);
-//@line 147 "/builds/slave/191-lnx-ntly/build/modules/libpref/src/init/all.js"
+//@line 161 "/builds/moz2_slave/mozilla-1.9.2-linux-nightly/build/modules/libpref/src/init/all.js"
 
 // Whether to autostart a media element with an |autoplay| attribute
 pref("media.autoplay.enabled", true);
@@ -154,15 +161,13 @@ pref("gfx.color_management.display_profile", "");
 pref("gfx.color_management.rendering_intent", 0);
 
 pref("gfx.downloadable_fonts.enabled", true);
-pref("gfx.downloadable_fonts.sanitize", true);
-//@line 162 "/builds/slave/191-lnx-ntly/build/modules/libpref/src/init/all.js"
-pref("gfx.downloadable_fonts.sanitize.preserve_otl_tables", true);
-//@line 164 "/builds/slave/191-lnx-ntly/build/modules/libpref/src/init/all.js"
 
 pref("accessibility.browsewithcaret", false);
 pref("accessibility.warn_on_browsewithcaret", true);
 
-//@line 169 "/builds/slave/191-lnx-ntly/build/modules/libpref/src/init/all.js"
+pref("accessibility.browsewithcaret_shortcut.enabled", true);
+
+//@line 179 "/builds/moz2_slave/mozilla-1.9.2-linux-nightly/build/modules/libpref/src/init/all.js"
 // Tab focus model bit field:
 // 1 focuses text controls, 2 focuses other form elements, 4 adds links.
 // Most users will want 1, 3, or 7.
@@ -175,7 +180,7 @@ pref("accessibility.tabfocus_applies_to_xul", false);
 // unless this preference was set manually
 pref("ui.scrollToClick", 0);
 
-//@line 185 "/builds/slave/191-lnx-ntly/build/modules/libpref/src/init/all.js"
+//@line 195 "/builds/moz2_slave/mozilla-1.9.2-linux-nightly/build/modules/libpref/src/init/all.js"
 
 pref("accessibility.usetexttospeech", "");
 pref("accessibility.usebrailledisplay", "");
@@ -230,9 +235,6 @@ pref("nglayout.events.dispatchLeftClickOnly", true);
 // whether or not to draw images while dragging
 pref("nglayout.enable_drag_images", true);
 
-// whether or not to use xbl form controls
-pref("nglayout.debug.enable_xbl_forms", false);
-
 // scrollbar snapping region
 // 0 - off
 // 1 and higher - slider thickness multiple
@@ -522,10 +524,9 @@ pref("dom.storage.enabled", true);
 pref("dom.storage.default_quota",      5120);
 
 // Parsing perf prefs. For now just mimic what the old code did.
-pref("content.sink.event_probe_rate", 3);
-//@line 533 "/builds/slave/191-lnx-ntly/build/modules/libpref/src/init/all.js"
+//@line 539 "/builds/moz2_slave/mozilla-1.9.2-linux-nightly/build/modules/libpref/src/init/all.js"
 pref("content.sink.pending_event_mode", 0);
-//@line 535 "/builds/slave/191-lnx-ntly/build/modules/libpref/src/init/all.js"
+//@line 541 "/builds/moz2_slave/mozilla-1.9.2-linux-nightly/build/modules/libpref/src/init/all.js"
 
 // Disable popups from plugins by default
 //   0 = openAllowed
@@ -536,14 +537,18 @@ pref("privacy.popups.disable_from_plugins", 2);
 pref("dom.event.contextmenu.enabled",       true);
 
 pref("javascript.enabled",                  true);
-pref("javascript.allow.mailnews",           false);
 pref("javascript.options.strict",           false);
 pref("javascript.options.relimit",          false);
 pref("javascript.options.jit.content",      true);
-pref("javascript.options.jit.chrome",       false);
+pref("javascript.options.jit.chrome",       true);
+// This preference limits the memory usage of javascript.
+// If you want to change these values for your device,
+// please find Bug 417052 comment 17 and Bug 456721
+// Comment 32.
+pref("javascript.options.mem.high_water_mark", 32);
+pref("javascript.options.mem.gc_frequency",   1600);
 
 // advanced prefs
-pref("security.enable_java",                true);
 pref("advanced.mailftp",                    false);
 pref("image.animation_mode",                "normal");
 
@@ -570,7 +575,7 @@ pref("network.protocol-handler.external.data", false);
 pref("network.protocol-handler.external.ms-help", false);
 pref("network.protocol-handler.external.shell", false);
 pref("network.protocol-handler.external.vnd.ms.radio", false);
-//@line 582 "/builds/slave/191-lnx-ntly/build/modules/libpref/src/init/all.js"
+//@line 592 "/builds/moz2_slave/mozilla-1.9.2-linux-nightly/build/modules/libpref/src/init/all.js"
 pref("network.protocol-handler.external.disk", false);
 pref("network.protocol-handler.external.disks", false);
 pref("network.protocol-handler.external.afp", false);
@@ -613,7 +618,12 @@ pref("network.http.default-socket-type", "");
 
 pref("network.http.keep-alive", true); // set it to false in case of problems
 pref("network.http.proxy.keep-alive", true);
-pref("network.http.keep-alive.timeout", 300);
+// There is a problem with some IIS7 servers that don't close the connection
+// properly after it times out (bug #491541). Default timeout on IIS7 is
+// 120 seconds. We need to reuse or drop the connection within this time.
+// We set the timeout a little shorter to keep a reserve for cases when
+// the packet is lost or delayed on the route.
+pref("network.http.keep-alive.timeout", 115);
 
 // limit the absolute number of http connections.
 pref("network.http.max-connections", 30);
@@ -701,7 +711,6 @@ pref("network.IDN.whitelist.es", true);
 pref("network.IDN.whitelist.fi", true);
 pref("network.IDN.whitelist.gr", true);
 pref("network.IDN.whitelist.hu", true);
-pref("network.IDN.whitelist.il", true);
 pref("network.IDN.whitelist.io", true);
 pref("network.IDN.whitelist.ir", true);
 pref("network.IDN.whitelist.is", true);
@@ -709,10 +718,7 @@ pref("network.IDN.whitelist.jp", true);
 pref("network.IDN.whitelist.kr", true);
 pref("network.IDN.whitelist.li", true);
 pref("network.IDN.whitelist.lt", true);
-pref("network.IDN.whitelist.lu", true);
 pref("network.IDN.whitelist.no", true);
-pref("network.IDN.whitelist.nu", true);
-pref("network.IDN.whitelist.nz", true);
 pref("network.IDN.whitelist.pl", true);
 pref("network.IDN.whitelist.pr", true);
 pref("network.IDN.whitelist.se", true);
@@ -720,44 +726,14 @@ pref("network.IDN.whitelist.sh", true);
 pref("network.IDN.whitelist.th", true);
 pref("network.IDN.whitelist.tm", true);
 pref("network.IDN.whitelist.tw", true);
-pref("network.IDN.whitelist.ua", true);
 pref("network.IDN.whitelist.vn", true);
 
-// IDN ccTLDs
-// ae, UAE, .<Emarat>
-pref("network.IDN.whitelist.xn--mgbaam7a8h", true); 
-// cn, China, .<China> with variants
-pref("network.IDN.whitelist.xn--fiqz9s", true); // Traditional
-pref("network.IDN.whitelist.xn--fiqs8s", true); // Simplified
-// eg, Egypt, .<Masr>
-pref("network.IDN.whitelist.xn--wgbh1c", true);
-// hk, Hong Kong, .<Hong Kong>
-pref("network.IDN.whitelist.xn--j6w193g", true);
-// ir, Iran, <.Iran> with variants
-pref("network.IDN.whitelist.xn--mgba3a4f16a", true);
-pref("network.IDN.whitelist.xn--mgba3a4fra", true);
-// jo, Jordan, .<Al-Ordon>
-pref("network.IDN.whitelist.xn--mgbayh7gpa", true);
-// qa, Qatar, .<Qatar>
-pref("network.IDN.whitelist.xn--wgbl6a", true);
-// ru, Russian Federation, .<RF>
-pref("network.IDN.whitelist.xn--p1ai", true);
-// sa, Saudi Arabia, .<al-Saudiah> with variants
-pref("network.IDN.whitelist.xn--mgberp4a5d4ar", true); 
-pref("network.IDN.whitelist.xn--mgberp4a5d4a87g", true);
-pref("network.IDN.whitelist.xn--mgbqly7c0a67fbc", true);
-pref("network.IDN.whitelist.xn--mgbqly7cvafr", true);
-// tw, Taiwan, <.Taiwan> with variants
-pref("network.IDN.whitelist.xn--kpry57d", true);  // Traditional
-pref("network.IDN.whitelist.xn--kprw13d", true);  // Simplified
-
-// gTLDs
+// non-ccTLDs
 pref("network.IDN.whitelist.biz", true);
 pref("network.IDN.whitelist.cat", true);
 pref("network.IDN.whitelist.info", true);
 pref("network.IDN.whitelist.museum", true);
 pref("network.IDN.whitelist.org", true);
-pref("network.IDN.whitelist.tel", true);
 
 // NOTE: Before these can be removed, one of bug 414812's tests must be updated
 //       or it will likely fail!  Please CC jwalden+bmo on the bug associated
@@ -837,7 +813,16 @@ pref("network.negotiate-auth.gsslib", "");
 // Specify if the gss lib comes standard with the OS
 pref("network.negotiate-auth.using-native-gsslib", true);
 
-//@line 854 "/builds/slave/191-lnx-ntly/build/modules/libpref/src/init/all.js"
+//@line 835 "/builds/moz2_slave/mozilla-1.9.2-linux-nightly/build/modules/libpref/src/init/all.js"
+
+// Controls which NTLM authentication implementation we default to. True forces
+// the use of our generic (internal) NTLM authentication implementation vs. any
+// native implementation provided by the os. This pref is for diagnosing issues
+// with native NTLM. (See bug 520607 for details.) Using generic NTLM authentication
+// can expose the user to reflection attack vulnerabilities. Do not change this
+// unless you know what you're doing!
+// This pref should be removed 6 months after the release of firefox 3.6. 
+pref("network.auth.force-generic-ntlm", false);
 
 // The following prefs are used to enable automatic use of the operating
 // system's NTLM implementation to silently authenticate the user with their
@@ -856,9 +841,9 @@ pref("network.ntlm.send-lm-response", false);
 
 pref("permissions.default.image",           1); // 1-Accept, 2-Deny, 3-dontAcceptForeign
 
-//@line 874 "/builds/slave/191-lnx-ntly/build/modules/libpref/src/init/all.js"
+//@line 864 "/builds/moz2_slave/mozilla-1.9.2-linux-nightly/build/modules/libpref/src/init/all.js"
 pref("network.proxy.type",                  5);
-//@line 881 "/builds/slave/191-lnx-ntly/build/modules/libpref/src/init/all.js"
+//@line 871 "/builds/moz2_slave/mozilla-1.9.2-linux-nightly/build/modules/libpref/src/init/all.js"
 
 pref("network.proxy.ftp",                   "");
 pref("network.proxy.ftp_port",              0);
@@ -902,7 +887,7 @@ pref("intl.charsetmenu.browser.more2",      "chrome://global/locale/intl.propert
 pref("intl.charsetmenu.browser.more3",      "chrome://global/locale/intl.properties");
 pref("intl.charsetmenu.browser.more4",      "chrome://global/locale/intl.properties");
 pref("intl.charsetmenu.browser.more5",      "chrome://global/locale/intl.properties");
-pref("intl.charsetmenu.browser.unicode",    "chrome://global/locale/intl.properties");
+pref("intl.charsetmenu.browser.unicode",    "UTF-8, UTF-16LE, UTF-16BE, UTF-32, UTF-32LE, UTF-32BE");
 pref("intl.charsetmenu.mailedit",           "chrome://global/locale/intl.properties");
 pref("intl.charsetmenu.browser.cache",      "");
 pref("intl.charsetmenu.mailview.cache",     "");
@@ -918,6 +903,11 @@ pref("intl.locale.matchOS",                 false);
 pref("intl.fallbackCharsetList.ISO-8859-1", "windows-1252");
 pref("font.language.group",                 "chrome://global/locale/intl.properties");
 
+// these locales have right-to-left UI
+pref("intl.uidirection.ar", "rtl");
+pref("intl.uidirection.he", "rtl");
+pref("intl.uidirection.fa", "rtl");
+
 pref("font.mathfont-family", "STIXNonUnicode, STIXSize1, STIXGeneral, Standard Symbols L, DejaVu Sans, Cambria Math");
 
 // Some CJK fonts have bad underline offset, their CJK character glyphs are overlapped (or adjoined)  to its underline.
@@ -966,9 +956,28 @@ pref("mousewheel.transaction.ignoremovedelay", 100);
 // Macbook touchpad two finger pixel scrolling
 pref("mousewheel.enable_pixel_scrolling", true);
 
+// prefs for app level mouse wheel scrolling acceleration.
+// number of mousewheel clicks when acceleration starts
+// acceleration can be turned off if pref is set to -1
+pref("mousewheel.acceleration.start", -1);
+// factor to be multiplied for constant acceleration
+pref("mousewheel.acceleration.factor", 10);
+
+// Prefs for override the system mouse wheel scrolling speed on the root
+// content of the web pages.  When
+// "mousewheel.system_scroll_override_on_root_content.enabled" is true and the system
+// scrolling speed isn't customized by the user, the root content scrolling
+// speed is multiplied by the following factors.  The value will be used as
+// 1/100.  E.g., 200 means 2.00.
+// NOTE: Even if "mousewheel.system_scroll_override_on_root_content.enabled" is
+// true, when Gecko detects the user customized the system scrolling speed
+// settings, the override isn't executed.
+pref("mousewheel.system_scroll_override_on_root_content.vertical.factor", 200);
+pref("mousewheel.system_scroll_override_on_root_content.horizontal.factor", 200);
+
 // 0=lines, 1=pages, 2=history , 3=text size
 pref("mousewheel.withnokey.action",0);
-pref("mousewheel.withnokey.numlines",1);	
+pref("mousewheel.withnokey.numlines",6);
 pref("mousewheel.withnokey.sysnumlines",true);
 pref("mousewheel.withcontrolkey.action",0);
 pref("mousewheel.withcontrolkey.numlines",1);
@@ -1114,7 +1123,7 @@ pref("layout.css.report_errors", true);
 // Should the :visited selector ever match (otherwise :link matches instead)?
 pref("layout.css.visited_links_enabled", true);
 
-// Override DPI. A value of -1 means use the maximum of 96 and the system DPI.
+// Override DPI. A value of -1 means use the maxium of 96 and the system DPI.
 // A value of 0 means use the system DPI. A positive value is used as the DPI.
 // This sets the physical size of a device pixel and thus controls the
 // interpretation of physical units such as "pt".
@@ -1124,7 +1133,7 @@ pref("layout.css.dpi", -1);
 // automatically based on the DPI. A positive value is used as-is. This effectively
 // controls the size of a CSS "px". This is only used for pixel-based
 // (screen) output devices.
-pref("layout.css.devPixelsPerPx", -1);
+pref("layout.css.devPixelsPerPx", "-1");
 
 // pref for which side vertical scrollbars should be on
 // 0 = end-side in UI direction
@@ -1182,11 +1191,11 @@ pref("gestures.enable_single_finger_input", true);
 pref("editor.resizing.preserve_ratio",       true);
 pref("editor.positioning.offset",            0);
 
-// Disable slow script warnings for chrome by default - bug 492410
-pref("dom.max_chrome_script_run_time", 0);
+pref("dom.max_chrome_script_run_time", 20);
 pref("dom.max_script_run_time", 10);
 
 pref("svg.enabled", true);
+pref("svg.smil.enabled", false);
 
 pref("font.minimum-size.ar", 0);
 pref("font.minimum-size.x-armn", 0);
@@ -1220,15 +1229,15 @@ pref("font.minimum-size.x-western", 0);
 pref("font.minimum-size.x-unicode", 0);
 pref("font.minimum-size.x-user-def", 0);
 
-//@line 1621 "/builds/slave/191-lnx-ntly/build/modules/libpref/src/init/all.js"
+//@line 1654 "/builds/moz2_slave/mozilla-1.9.2-linux-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2038 "/builds/slave/191-lnx-ntly/build/modules/libpref/src/init/all.js"
+//@line 2078 "/builds/moz2_slave/mozilla-1.9.2-linux-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2239 "/builds/slave/191-lnx-ntly/build/modules/libpref/src/init/all.js"
+//@line 2281 "/builds/moz2_slave/mozilla-1.9.2-linux-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2333 "/builds/slave/191-lnx-ntly/build/modules/libpref/src/init/all.js"
+//@line 2377 "/builds/moz2_slave/mozilla-1.9.2-linux-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2336 "/builds/slave/191-lnx-ntly/build/modules/libpref/src/init/all.js"
+//@line 2380 "/builds/moz2_slave/mozilla-1.9.2-linux-nightly/build/modules/libpref/src/init/all.js"
 // Handled differently under Mac/Windows
 pref("network.hosts.smtp_server", "localhost");
 pref("network.hosts.pop_server", "pop");
@@ -1496,15 +1505,17 @@ pref("print.postscript.print_command", "lpr ${MOZ_PRINTER_NAME:+-P\"$MOZ_PRINTER
 // So, we have no reasons we should use non-toplevel window for popup.
 pref("ui.panel.default_level_parent", true);
 
-//@line 2606 "/builds/slave/191-lnx-ntly/build/modules/libpref/src/init/all.js"
+pref("mousewheel.system_scroll_override_on_root_content.enabled", false);
 
-//@line 2674 "/builds/slave/191-lnx-ntly/build/modules/libpref/src/init/all.js"
+//@line 2652 "/builds/moz2_slave/mozilla-1.9.2-linux-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2700 "/builds/slave/191-lnx-ntly/build/modules/libpref/src/init/all.js"
+//@line 2720 "/builds/moz2_slave/mozilla-1.9.2-linux-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2720 "/builds/slave/191-lnx-ntly/build/modules/libpref/src/init/all.js"
+//@line 2746 "/builds/moz2_slave/mozilla-1.9.2-linux-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2728 "/builds/slave/191-lnx-ntly/build/modules/libpref/src/init/all.js"
+//@line 2766 "/builds/moz2_slave/mozilla-1.9.2-linux-nightly/build/modules/libpref/src/init/all.js"
+
+//@line 2774 "/builds/moz2_slave/mozilla-1.9.2-linux-nightly/build/modules/libpref/src/init/all.js"
 
 // Login Manager prefs
 pref("signon.rememberSignons",              true);
@@ -1515,6 +1526,16 @@ pref("signon.SignonFileName3",              "signons3.txt"); // obsolete
 pref("signon.autofillForms",                true); 
 pref("signon.debug",                        false); // logs to Error Console
 
+// Satchel (Form Manager) prefs
+pref("browser.formfill.debug",            false);
+pref("browser.formfill.enable",           true);
+pref("browser.formfill.agedWeight",       2);
+pref("browser.formfill.bucketSize",       1);
+pref("browser.formfill.maxTimeGroupings", 25);
+pref("browser.formfill.timeGroupingSize", 604800);
+pref("browser.formfill.boundaryWeight",   25);
+pref("browser.formfill.prefixWeight",     5);
+
 // Zoom prefs
 pref("browser.zoom.full", false);
 pref("zoom.minPercent", 30);
@@ -1528,7 +1549,15 @@ pref("image.cache.size", 5242880);
 // Size is given a weight of 1000 - timeweight.
 pref("image.cache.timeweight", 500);
 
-//@line 2757 "/builds/slave/191-lnx-ntly/build/modules/libpref/src/init/all.js"
+// The default Accept header sent for images loaded over HTTP(S)
+pref("image.http.accept", "image/png,image/*;q=0.8,*/*;q=0.5");
+
+//@line 2816 "/builds/moz2_slave/mozilla-1.9.2-linux-nightly/build/modules/libpref/src/init/all.js"
+
+//@line 2821 "/builds/moz2_slave/mozilla-1.9.2-linux-nightly/build/modules/libpref/src/init/all.js"
 
 // Enable/Disable the geolocation API for content
 pref("geo.enabled", true);
+
+// Enable/Disable HTML5 parser
+pref("html5.enable", false);
